@@ -10,6 +10,10 @@
 #'   Load average (of the last 5 min) at which the worker is considered occupied,
 #'   so that no job can be submitted.
 #'   Default is \code{ncpus-1}.
+#' @param r.options [\code{character}]
+#'   Options for R and Rscript, one option per element of the vector, 
+#'   a la \dQuote{--vanilla}.
+#'   Default is \code{c("--no-save", "--no-restore", "--no-init-file", "--no-site-file")}.
 #' @param script [\code{character(1)}]\cr
 #'   Path to helper bash script which interacts with the worker.
 #'   You really should not have to touch this, as this would imply that we have screwed up and
@@ -21,8 +25,10 @@
 #'   Default means to take it from package directory.
 #' @return [\code{\link{ClusterFunctions}}].
 #' @export
-makeClusterFunctionsMulticore = function(ncpus, max.jobs, max.load, script) {
-  worker = makeWorkerLocalLinux(script, ncpus, max.jobs, max.load)
+makeClusterFunctionsMulticore = function(ncpus, max.jobs, max.load, 
+  r.options=c("--no-save", "--no-restore", "--no-init-file", "--no-site-file"), script) {
+  
+  worker = makeWorkerLocalLinux(r.options, script, ncpus, max.jobs, max.load)
   workers = list(localhost=worker)
 
   submitJob = function(conf, reg, job.name, rscript, log.file, job.dir, resources) {
