@@ -8,11 +8,11 @@
 #' appropriate privileges to submit, delete and list jobs on the
 #' cluster (this is usually the case).
 #'
-#' The template file can use any of the resources defined for the job
-#' by accessing the appropriate element of the \code{resources}
-#' list. It is the template file's job to choose a queue for the job
-#' and add any desired resource allocations. A simple example
-#' is provided here
+#' The template file can access all arguments passed to the 
+#' \code{submitJob} function, see here \code{\link{ClusterFunctions}}.
+#' It is the template file's job to choose a queue for the job
+#' and handle the desired resource allocations. 
+#' A simple example is provided here
 #' \url{http://code.google.com/p/batchjobs/source/browse/trunk/BatchJobs/examples/cfTorque/simple.tmpl}
 #' and a more complex one here
 #' \url{http://code.google.com/p/batchjobs/source/browse/trunk/BatchJobs/examples/cfTorque/lido.tmpl}
@@ -22,51 +22,26 @@
 #'   Path to a brew template file that is used for the PBS job file.
 #' @return [\code{\link{ClusterFunctions}}].
 #' @export
-#  FIXME document what variables are avial. in brew templ. 
 makeClusterFunctionsTorque = function(template.file) {
-  checkArg(template.file, "character", len=1L, na.ok=FALSE)
-  ## Read in template
-  fd = file(template.file, "r")
-  template = paste(readLines(fd), collapse="\n")
-  close(fd)
+  template = cfReadBrewTemplate(template.file)
 
   submitJob = function(conf, reg, job.name, rscript, log.file, job.dir, resources) {
-    if (conf$debug) {
-      # if not temp, use jobs dir
-      outfile = sub("\\.R$", ".pbs", rscript)
-    } else {
-      outfile = tempfile()
-    }
-    brewWithStop(text=template, output=outfile)
+    outfile = cfBrewTemplate(conf, template, rscript, "pbs")
     res = runOSCommandLinux("qsub", outfile, stop.on.exit.code=FALSE)
 
     max.jobs.msg = "Maximum number of jobs already in queue"
-    if (grepl(max.jobs.msg, res$output, fixed=TRUE)) {
+    output = collapse(res$output, sep="\n")
+    if (grepl(max.jobs.msg, output, fixed=TRUE)) {
       makeSubmitJobResult(status=1L, batch.job.id=NA_character_, msg=max.jobs.msg)
     } else if (res$exit.code > 0L) {
-      msg = sprintf("qsub produced exit code %i; output %s", res$exit.code, res$output)
-      makeSubmitJobResult(status=101L, msg=msg)
-    } else  {
-      makeSubmitJobResult(status=0L, batch.job.id=res$output)
+      cfHandleUnkownSubmitError("qsub", res$exit.code, res$output)
+    } else {
+      makeSubmitJobResult(status=0L, batch.job.id=trim(output))
     }
   }
 
   killJob = function(conf, reg, batch.job.id) {
-    tries = 0L
-    while(TRUE) {
-      # qdel sends SIGTERM, delay, SIGKILL
-      res = runOSCommandLinux("qdel", batch.job.id, stop.on.exit.code=FALSE)
-      if (res$exit.code == 0L) {
-        return()
-      } else {
-        tries = tries + 1L
-        if (tries > 3L) {
-          stopf("Really tried to kill job, but could not do it. batch job id is %s.\nMessage: %s",
-            batch.job.id, res$output)
-        }
-        Sys.sleep(1)
-      }
-    }
+    cfKillBatchJob("qdel", batch.job.id)
   }
 
   listJobs = function(conf, reg) {
