@@ -18,7 +18,9 @@
 #'   sequentially as a single job for the scheduler.
 #'   Default is all jobs which were not yet submitted to the batch system.
 #' @param resources [\code{list}]\cr
-#'   Required resources for all batch jobs.
+#'   Required resources for all batch jobs. The elements of this list
+#'   (e.g. something like \dQuote{walltime} or \dQuote{nodes} are defined by your template job file.
+#'   Defaults can be specified in your config file.  
 #'   Default is empty list.
 #' @param wait [\code{function(retries)}]\cr
 #'   Function that defines how many seconds should be waited in case of a temporary error.
@@ -28,15 +30,15 @@
 #'   (like filled queues). Each time \code{wait} is called to wait a certain
 #'   number of seconds.
 #'   Default is 10 times.
-#' @param job.delay [\code{function(n, i)}]\cr
+#' @param job.delay [\code{function(n, i)} or \code{logical(1)}]\cr
 #'   Function that defines how many seconds a job should be delayed before it starts.
-#'   This is an expert option and only necessary to change, when you want submit
+#'   This is an expert option and only necessary to change when you want submit
 #'   extremely many jobs. We then delay the jobs a bit to write the submit messages as
 #'   early as possible to avoid writer starvation.
-#'   \code{n} is the number of jobs and \code{i} the number of
-#'   the ith job.
-#'   The default is no delay for less than 100 jobs and otherwise
-#'   \code{runif(1, 0.1*n, 0.2*n)}.
+#'   \code{n} is the number of jobs and \code{i} the number of the ith job.
+#'   The default function used with \code{job.delay} set to \code{TRUE} is no delay for
+#'   100 jobs or less and otherwise \code{runif(1, 0.1*n, 0.2*n)}.
+#'   If set to \code{FALSE} (the default) delaying jobs is disabled.
 #' @return Vector of submitted job ids.
 #' @export
 #' @examples
@@ -44,7 +46,9 @@
 #' f <- function(x) x^2
 #' batchMap(reg, f, 1:10)
 #' submitJobs(reg)
-submitJobs = function(reg, ids, resources=list(), wait, max.retries=10L, job.delay) {
+submitJobs = function(reg, ids, resources=list(), wait, max.retries=10L, job.delay=FALSE) {
+  conf = getBatchJobsConf()
+  cf = getClusterFunctions(conf)
 
   checkArg(reg, cl="Registry")
   if (missing(ids)) {
@@ -68,8 +72,7 @@ submitJobs = function(reg, ids, resources=list(), wait, max.retries=10L, job.del
     checkIdsPresent(reg, unlist(ids))
   }
   checkArg(resources, "list")
-  if(!isProperlyNamed(resources))
-    stop("'resources' must be all be uniquely named!")
+  resources = do.call(resrc, resources)         
 
   if (missing(wait))
     wait = function(retries) 10 * 2^retries # ^ always converts to double
@@ -81,11 +84,16 @@ submitJobs = function(reg, ids, resources=list(), wait, max.retries=10L, job.del
     checkArg(max.retries, "integer", len=1L, na.ok=FALSE)
   }
 
-  if (missing(job.delay)) {
-    job.delay = function(n, i)
-      if (n > 100L) runif(1L, n*0.1, n*0.2) else 0
+  if (is.logical(job.delay)) {
+    n = length(ids)
+    if (job.delay && n > 100L && cf$name %nin% c("Interactive", "Multicore", "SSH")) {
+      delays = runif(n, n*0.1, n*0.2)
+    } else {
+      delays = rep(0, n)
+    }
   } else {
     checkArg(job.delay, formals=c("n", "i"))
+    delays = vapply(seq_along(ids), job.delay, numeric(1L), n=length(ids))
   }
 
   if (!is.null(getListJobs())) {
@@ -98,8 +106,6 @@ submitJobs = function(reg, ids, resources=list(), wait, max.retries=10L, job.del
   saveConf(reg)
 
   is.chunks = is.list(ids)
-  conf = getBatchJobsConf()
-  cf = getClusterFunctions(conf)
   messagef("Submitting %i chunks / %i jobs.",
     length(ids), if(is.chunks) sum(vapply(ids, length, integer(1L))) else length(ids))
   messagef("Cluster functions: %s.", cf$name)
@@ -115,7 +121,8 @@ submitJobs = function(reg, ids, resources=list(), wait, max.retries=10L, job.del
     # we need the second case for errors in brew (e.g. resources)
     if(interrupted && exists("batch.result", inherits=FALSE)) {
       submit.msgs$push(dbMakeMessageSubmitted(reg, id, time=submit.time,
-        batch.job.id=batch.result$batch.job.id, first.job.in.chunk.id = if(is.chunks) id1 else NULL))
+        batch.job.id=batch.result$batch.job.id, first.job.in.chunk.id = if(is.chunks) id1 else NULL,
+        resources.timestamp=resources.timestamp))
     }
     # if we have remaining messages send them now
     messagef("Sending %i submit messages...\nMight take some time, do not interrupt this!",
@@ -125,8 +132,8 @@ submitJobs = function(reg, ids, resources=list(), wait, max.retries=10L, job.del
 
   # write R scripts before so we save some time in the important loop
   messagef("Writing %i R scripts...", length(ids))
-  delays = vapply(seq_along(ids), job.delay, numeric(1L), n=length(ids))
-  writeRscripts(reg, ids, disable.mail=FALSE, delays=delays,
+  resources.timestamp = saveResources(reg, resources)
+  writeRscripts(reg, ids, resources.timestamp, disable.mail=FALSE, delays=delays,
                interactive.test = !is.null(conf$interactive))
 
   bar = makeProgressBar(max=length(ids), label="submitJobs               ")
@@ -151,7 +158,8 @@ submitJobs = function(reg, ids, resources=list(), wait, max.retries=10L, job.del
         # validate status returned from cluster functions
         if (batch.result$status == 0L) {
           submit.msgs$push(dbMakeMessageSubmitted(reg, id, time=submit.time,
-            batch.job.id=batch.result$batch.job.id, first.job.in.chunk.id = if(is.chunks) id1 else NULL))
+            batch.job.id=batch.result$batch.job.id, first.job.in.chunk.id = if(is.chunks) id1 else NULL,
+            resources.timestamp=resources.timestamp))
           interrupted = FALSE
           bar$inc(1L)
           break
@@ -174,11 +182,9 @@ submitJobs = function(reg, ids, resources=list(), wait, max.retries=10L, job.del
           next
         }
 
+        # fatal error, abort at once
         if (batch.result$status > 100L && batch.result$status <= 200L) {
-          # fatal error, abort at once
-          message("Fatal error occured: ", batch.result$status)
-          message("Fatal error msg: ", batch.result$msg)
-          stop("Fatal error occured: ", batch.result$status)
+          stopf("Fatal error occured: %i. %s", batch.result$status, batch.result$msg)
         }
 
         stopf("Illegal status code %s returned from cluster functions!", batch.result$status)
